GO-2026-5703: OpenMeter: SQL injection through meter creation in github.com/openmeterio/openmeter
package
Version:
v1.0.0-beta.206
Opens a new window with list of versions in this module.
Published: Apr 4, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 33
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type PromQuery struct {
Name string `json:"name"`
PromQL string `json:"promql"`
}
type QueryResult struct {
Name string `json:"name"`
Query string `json:"query"`
Timestamp time.Time `json:"timestamp"`
Values model.Vector `json:"values"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.