Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Map ¶
Represents a point in time balance of grants
func (Map) ExactlyForGrants ¶
Whether the contents of the Map exactly matches the list of provided grants. Return false if it has additional grants or if it misses any grants
func (Map) OverrideWith ¶
type NoSavedBalanceForOwnerError ¶
type NoSavedBalanceForOwnerError struct {
Owner grant.NamespacedOwner
Time time.Time
}
No balance has been saved since start of measurement for the owner
func (NoSavedBalanceForOwnerError) Error ¶
func (e NoSavedBalanceForOwnerError) Error() string
type SnapshotRepo ¶
type SnapshotRepo interface {
InvalidateAfter(ctx context.Context, owner grant.NamespacedOwner, at time.Time) error
GetLatestValidAt(ctx context.Context, owner grant.NamespacedOwner, at time.Time) (Snapshot, error)
Save(ctx context.Context, owner grant.NamespacedOwner, balances []Snapshot) error
entutils.TxCreator
entutils.TxUser[SnapshotRepo]
}
Click to show internal directories.
Click to hide internal directories.