billinginvoiceusagebasedlineconfig

package
v1.0.0-beta.227 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the billinginvoiceusagebasedlineconfig type in the database.
	Label = "billing_invoice_usage_based_line_config"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldNamespace holds the string denoting the namespace field in the database.
	FieldNamespace = "namespace"
	// FieldPriceType holds the string denoting the price_type field in the database.
	FieldPriceType = "price_type"
	// FieldFeatureKey holds the string denoting the feature_key field in the database.
	FieldFeatureKey = "feature_key"
	// FieldPrice holds the string denoting the price field in the database.
	FieldPrice = "price"
	// FieldPreLinePeriodQuantity holds the string denoting the pre_line_period_quantity field in the database.
	FieldPreLinePeriodQuantity = "pre_line_period_quantity"
	// FieldMeteredPreLinePeriodQuantity holds the string denoting the metered_pre_line_period_quantity field in the database.
	FieldMeteredPreLinePeriodQuantity = "metered_pre_line_period_quantity"
	// FieldMeteredQuantity holds the string denoting the metered_quantity field in the database.
	FieldMeteredQuantity = "metered_quantity"
	// Table holds the table name of the billinginvoiceusagebasedlineconfig in the database.
	Table = "billing_invoice_usage_based_line_configs"
)

Variables

var (
	// NamespaceValidator is a validator for the "namespace" field. It is called by the builders before save.
	NamespaceValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
	// ValueScanner of all BillingInvoiceUsageBasedLineConfig fields.
	ValueScanner struct {
		Price field.TypeValueScanner[*productcatalog.Price]
	}
)

Columns holds all SQL columns for billinginvoiceusagebasedlineconfig fields.

Functions

func And

And groups predicates with the AND operator between them.

func FeatureKey

FeatureKey applies equality check predicate on the "feature_key" field. It's identical to FeatureKeyEQ.

func FeatureKeyContains

FeatureKeyContains applies the Contains predicate on the "feature_key" field.

func FeatureKeyContainsFold

func FeatureKeyContainsFold(v string) predicate.BillingInvoiceUsageBasedLineConfig

FeatureKeyContainsFold applies the ContainsFold predicate on the "feature_key" field.

func FeatureKeyEQ

FeatureKeyEQ applies the EQ predicate on the "feature_key" field.

func FeatureKeyEqualFold

FeatureKeyEqualFold applies the EqualFold predicate on the "feature_key" field.

func FeatureKeyGT

FeatureKeyGT applies the GT predicate on the "feature_key" field.

func FeatureKeyGTE

FeatureKeyGTE applies the GTE predicate on the "feature_key" field.

func FeatureKeyHasPrefix

FeatureKeyHasPrefix applies the HasPrefix predicate on the "feature_key" field.

func FeatureKeyHasSuffix

FeatureKeyHasSuffix applies the HasSuffix predicate on the "feature_key" field.

func FeatureKeyIn

FeatureKeyIn applies the In predicate on the "feature_key" field.

func FeatureKeyIsNil

FeatureKeyIsNil applies the IsNil predicate on the "feature_key" field.

func FeatureKeyLT

FeatureKeyLT applies the LT predicate on the "feature_key" field.

func FeatureKeyLTE

FeatureKeyLTE applies the LTE predicate on the "feature_key" field.

func FeatureKeyNEQ

FeatureKeyNEQ applies the NEQ predicate on the "feature_key" field.

func FeatureKeyNotIn

FeatureKeyNotIn applies the NotIn predicate on the "feature_key" field.

func FeatureKeyNotNil

FeatureKeyNotNil applies the NotNil predicate on the "feature_key" field.

func ID

ID filters vertices based on their ID field.

func IDContainsFold

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

IDNotIn applies the NotIn predicate on the ID field.

func MeteredPreLinePeriodQuantity

func MeteredPreLinePeriodQuantity(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantity applies equality check predicate on the "metered_pre_line_period_quantity" field. It's identical to MeteredPreLinePeriodQuantityEQ.

func MeteredPreLinePeriodQuantityEQ

func MeteredPreLinePeriodQuantityEQ(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityEQ applies the EQ predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityGT

func MeteredPreLinePeriodQuantityGT(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityGT applies the GT predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityGTE

func MeteredPreLinePeriodQuantityGTE(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityGTE applies the GTE predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityIn

func MeteredPreLinePeriodQuantityIn(vs ...alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityIn applies the In predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityIsNil

func MeteredPreLinePeriodQuantityIsNil() predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityIsNil applies the IsNil predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityLT

func MeteredPreLinePeriodQuantityLT(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityLT applies the LT predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityLTE

func MeteredPreLinePeriodQuantityLTE(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityLTE applies the LTE predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityNEQ

func MeteredPreLinePeriodQuantityNEQ(v alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityNEQ applies the NEQ predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityNotIn

func MeteredPreLinePeriodQuantityNotIn(vs ...alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityNotIn applies the NotIn predicate on the "metered_pre_line_period_quantity" field.

func MeteredPreLinePeriodQuantityNotNil

func MeteredPreLinePeriodQuantityNotNil() predicate.BillingInvoiceUsageBasedLineConfig

MeteredPreLinePeriodQuantityNotNil applies the NotNil predicate on the "metered_pre_line_period_quantity" field.

func MeteredQuantity

MeteredQuantity applies equality check predicate on the "metered_quantity" field. It's identical to MeteredQuantityEQ.

func MeteredQuantityEQ

MeteredQuantityEQ applies the EQ predicate on the "metered_quantity" field.

func MeteredQuantityGT

MeteredQuantityGT applies the GT predicate on the "metered_quantity" field.

func MeteredQuantityGTE

MeteredQuantityGTE applies the GTE predicate on the "metered_quantity" field.

func MeteredQuantityIn

MeteredQuantityIn applies the In predicate on the "metered_quantity" field.

func MeteredQuantityIsNil

func MeteredQuantityIsNil() predicate.BillingInvoiceUsageBasedLineConfig

MeteredQuantityIsNil applies the IsNil predicate on the "metered_quantity" field.

func MeteredQuantityLT

MeteredQuantityLT applies the LT predicate on the "metered_quantity" field.

func MeteredQuantityLTE

MeteredQuantityLTE applies the LTE predicate on the "metered_quantity" field.

func MeteredQuantityNEQ

MeteredQuantityNEQ applies the NEQ predicate on the "metered_quantity" field.

func MeteredQuantityNotIn

MeteredQuantityNotIn applies the NotIn predicate on the "metered_quantity" field.

func MeteredQuantityNotNil

func MeteredQuantityNotNil() predicate.BillingInvoiceUsageBasedLineConfig

MeteredQuantityNotNil applies the NotNil predicate on the "metered_quantity" field.

func Namespace

Namespace applies equality check predicate on the "namespace" field. It's identical to NamespaceEQ.

func NamespaceContains

NamespaceContains applies the Contains predicate on the "namespace" field.

func NamespaceContainsFold

func NamespaceContainsFold(v string) predicate.BillingInvoiceUsageBasedLineConfig

NamespaceContainsFold applies the ContainsFold predicate on the "namespace" field.

func NamespaceEQ

NamespaceEQ applies the EQ predicate on the "namespace" field.

func NamespaceEqualFold

NamespaceEqualFold applies the EqualFold predicate on the "namespace" field.

func NamespaceGT

NamespaceGT applies the GT predicate on the "namespace" field.

func NamespaceGTE

NamespaceGTE applies the GTE predicate on the "namespace" field.

func NamespaceHasPrefix

NamespaceHasPrefix applies the HasPrefix predicate on the "namespace" field.

func NamespaceHasSuffix

NamespaceHasSuffix applies the HasSuffix predicate on the "namespace" field.

func NamespaceIn

NamespaceIn applies the In predicate on the "namespace" field.

func NamespaceLT

NamespaceLT applies the LT predicate on the "namespace" field.

func NamespaceLTE

NamespaceLTE applies the LTE predicate on the "namespace" field.

func NamespaceNEQ

NamespaceNEQ applies the NEQ predicate on the "namespace" field.

func NamespaceNotIn

NamespaceNotIn applies the NotIn predicate on the "namespace" field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func PreLinePeriodQuantity

PreLinePeriodQuantity applies equality check predicate on the "pre_line_period_quantity" field. It's identical to PreLinePeriodQuantityEQ.

func PreLinePeriodQuantityEQ

PreLinePeriodQuantityEQ applies the EQ predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityGT

PreLinePeriodQuantityGT applies the GT predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityGTE

PreLinePeriodQuantityGTE applies the GTE predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityIn

PreLinePeriodQuantityIn applies the In predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityIsNil

func PreLinePeriodQuantityIsNil() predicate.BillingInvoiceUsageBasedLineConfig

PreLinePeriodQuantityIsNil applies the IsNil predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityLT

PreLinePeriodQuantityLT applies the LT predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityLTE

PreLinePeriodQuantityLTE applies the LTE predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityNEQ

PreLinePeriodQuantityNEQ applies the NEQ predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityNotIn

func PreLinePeriodQuantityNotIn(vs ...alpacadecimal.Decimal) predicate.BillingInvoiceUsageBasedLineConfig

PreLinePeriodQuantityNotIn applies the NotIn predicate on the "pre_line_period_quantity" field.

func PreLinePeriodQuantityNotNil

func PreLinePeriodQuantityNotNil() predicate.BillingInvoiceUsageBasedLineConfig

PreLinePeriodQuantityNotNil applies the NotNil predicate on the "pre_line_period_quantity" field.

func PriceTypeEQ

PriceTypeEQ applies the EQ predicate on the "price_type" field.

func PriceTypeIn

PriceTypeIn applies the In predicate on the "price_type" field.

func PriceTypeNEQ

PriceTypeNEQ applies the NEQ predicate on the "price_type" field.

func PriceTypeNotIn

PriceTypeNotIn applies the NotIn predicate on the "price_type" field.

func PriceTypeValidator

func PriceTypeValidator(pt productcatalog.PriceType) error

PriceTypeValidator is a validator for the "price_type" field enum values. It is called by the builders before save.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the BillingInvoiceUsageBasedLineConfig queries.

func ByFeatureKey

func ByFeatureKey(opts ...sql.OrderTermOption) OrderOption

ByFeatureKey orders the results by the feature_key field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByMeteredPreLinePeriodQuantity

func ByMeteredPreLinePeriodQuantity(opts ...sql.OrderTermOption) OrderOption

ByMeteredPreLinePeriodQuantity orders the results by the metered_pre_line_period_quantity field.

func ByMeteredQuantity

func ByMeteredQuantity(opts ...sql.OrderTermOption) OrderOption

ByMeteredQuantity orders the results by the metered_quantity field.

func ByNamespace

func ByNamespace(opts ...sql.OrderTermOption) OrderOption

ByNamespace orders the results by the namespace field.

func ByPreLinePeriodQuantity

func ByPreLinePeriodQuantity(opts ...sql.OrderTermOption) OrderOption

ByPreLinePeriodQuantity orders the results by the pre_line_period_quantity field.

func ByPrice

func ByPrice(opts ...sql.OrderTermOption) OrderOption

ByPrice orders the results by the price field.

func ByPriceType

func ByPriceType(opts ...sql.OrderTermOption) OrderOption

ByPriceType orders the results by the price_type field.

Jump to