subject

package
v1.0.0-beta.218 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the subject type in the database.
	Label = "subject"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldNamespace holds the string denoting the namespace field in the database.
	FieldNamespace = "namespace"
	// FieldKey holds the string denoting the key field in the database.
	FieldKey = "key"
	// FieldDisplayName holds the string denoting the display_name field in the database.
	FieldDisplayName = "display_name"
	// FieldStripeCustomerID holds the string denoting the stripe_customer_id field in the database.
	FieldStripeCustomerID = "stripe_customer_id"
	// FieldMetadata holds the string denoting the metadata field in the database.
	FieldMetadata = "metadata"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// Table holds the table name of the subject in the database.
	Table = "subjects"
)

Variables

var (
	// NamespaceValidator is a validator for the "namespace" field. It is called by the builders before save.
	NamespaceValidator func(string) error
	// KeyValidator is a validator for the "key" field. It is called by the builders before save.
	KeyValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() string
)

Columns holds all SQL columns for subject fields.

Functions

func And

func And(predicates ...predicate.Subject) predicate.Subject

And groups predicates with the AND operator between them.

func CreatedAt

func CreatedAt(v time.Time) predicate.Subject

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Subject

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Subject

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Subject

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Subject

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Subject

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Subject

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Subject

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Subject

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func DisplayName

func DisplayName(v string) predicate.Subject

DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.

func DisplayNameContains

func DisplayNameContains(v string) predicate.Subject

DisplayNameContains applies the Contains predicate on the "display_name" field.

func DisplayNameContainsFold

func DisplayNameContainsFold(v string) predicate.Subject

DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.

func DisplayNameEQ

func DisplayNameEQ(v string) predicate.Subject

DisplayNameEQ applies the EQ predicate on the "display_name" field.

func DisplayNameEqualFold

func DisplayNameEqualFold(v string) predicate.Subject

DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.

func DisplayNameGT

func DisplayNameGT(v string) predicate.Subject

DisplayNameGT applies the GT predicate on the "display_name" field.

func DisplayNameGTE

func DisplayNameGTE(v string) predicate.Subject

DisplayNameGTE applies the GTE predicate on the "display_name" field.

func DisplayNameHasPrefix

func DisplayNameHasPrefix(v string) predicate.Subject

DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.

func DisplayNameHasSuffix

func DisplayNameHasSuffix(v string) predicate.Subject

DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.

func DisplayNameIn

func DisplayNameIn(vs ...string) predicate.Subject

DisplayNameIn applies the In predicate on the "display_name" field.

func DisplayNameIsNil

func DisplayNameIsNil() predicate.Subject

DisplayNameIsNil applies the IsNil predicate on the "display_name" field.

func DisplayNameLT

func DisplayNameLT(v string) predicate.Subject

DisplayNameLT applies the LT predicate on the "display_name" field.

func DisplayNameLTE

func DisplayNameLTE(v string) predicate.Subject

DisplayNameLTE applies the LTE predicate on the "display_name" field.

func DisplayNameNEQ

func DisplayNameNEQ(v string) predicate.Subject

DisplayNameNEQ applies the NEQ predicate on the "display_name" field.

func DisplayNameNotIn

func DisplayNameNotIn(vs ...string) predicate.Subject

DisplayNameNotIn applies the NotIn predicate on the "display_name" field.

func DisplayNameNotNil

func DisplayNameNotNil() predicate.Subject

DisplayNameNotNil applies the NotNil predicate on the "display_name" field.

func ID

func ID(id string) predicate.Subject

ID filters vertices based on their ID field.

func IDContainsFold

func IDContainsFold(id string) predicate.Subject

IDContainsFold applies the ContainsFold predicate on the ID field.

func IDEQ

func IDEQ(id string) predicate.Subject

IDEQ applies the EQ predicate on the ID field.

func IDEqualFold

func IDEqualFold(id string) predicate.Subject

IDEqualFold applies the EqualFold predicate on the ID field.

func IDGT

func IDGT(id string) predicate.Subject

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id string) predicate.Subject

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...string) predicate.Subject

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id string) predicate.Subject

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id string) predicate.Subject

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id string) predicate.Subject

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...string) predicate.Subject

IDNotIn applies the NotIn predicate on the ID field.

func Key

func Key(v string) predicate.Subject

Key applies equality check predicate on the "key" field. It's identical to KeyEQ.

func KeyContains

func KeyContains(v string) predicate.Subject

KeyContains applies the Contains predicate on the "key" field.

func KeyContainsFold

func KeyContainsFold(v string) predicate.Subject

KeyContainsFold applies the ContainsFold predicate on the "key" field.

func KeyEQ

func KeyEQ(v string) predicate.Subject

KeyEQ applies the EQ predicate on the "key" field.

func KeyEqualFold

func KeyEqualFold(v string) predicate.Subject

KeyEqualFold applies the EqualFold predicate on the "key" field.

func KeyGT

func KeyGT(v string) predicate.Subject

KeyGT applies the GT predicate on the "key" field.

func KeyGTE

func KeyGTE(v string) predicate.Subject

KeyGTE applies the GTE predicate on the "key" field.

func KeyHasPrefix

func KeyHasPrefix(v string) predicate.Subject

KeyHasPrefix applies the HasPrefix predicate on the "key" field.

func KeyHasSuffix

func KeyHasSuffix(v string) predicate.Subject

KeyHasSuffix applies the HasSuffix predicate on the "key" field.

func KeyIn

func KeyIn(vs ...string) predicate.Subject

KeyIn applies the In predicate on the "key" field.

func KeyLT

func KeyLT(v string) predicate.Subject

KeyLT applies the LT predicate on the "key" field.

func KeyLTE

func KeyLTE(v string) predicate.Subject

KeyLTE applies the LTE predicate on the "key" field.

func KeyNEQ

func KeyNEQ(v string) predicate.Subject

KeyNEQ applies the NEQ predicate on the "key" field.

func KeyNotIn

func KeyNotIn(vs ...string) predicate.Subject

KeyNotIn applies the NotIn predicate on the "key" field.

func MetadataIsNil

func MetadataIsNil() predicate.Subject

MetadataIsNil applies the IsNil predicate on the "metadata" field.

func MetadataNotNil

func MetadataNotNil() predicate.Subject

MetadataNotNil applies the NotNil predicate on the "metadata" field.

func Namespace

func Namespace(v string) predicate.Subject

Namespace applies equality check predicate on the "namespace" field. It's identical to NamespaceEQ.

func NamespaceContains

func NamespaceContains(v string) predicate.Subject

NamespaceContains applies the Contains predicate on the "namespace" field.

func NamespaceContainsFold

func NamespaceContainsFold(v string) predicate.Subject

NamespaceContainsFold applies the ContainsFold predicate on the "namespace" field.

func NamespaceEQ

func NamespaceEQ(v string) predicate.Subject

NamespaceEQ applies the EQ predicate on the "namespace" field.

func NamespaceEqualFold

func NamespaceEqualFold(v string) predicate.Subject

NamespaceEqualFold applies the EqualFold predicate on the "namespace" field.

func NamespaceGT

func NamespaceGT(v string) predicate.Subject

NamespaceGT applies the GT predicate on the "namespace" field.

func NamespaceGTE

func NamespaceGTE(v string) predicate.Subject

NamespaceGTE applies the GTE predicate on the "namespace" field.

func NamespaceHasPrefix

func NamespaceHasPrefix(v string) predicate.Subject

NamespaceHasPrefix applies the HasPrefix predicate on the "namespace" field.

func NamespaceHasSuffix

func NamespaceHasSuffix(v string) predicate.Subject

NamespaceHasSuffix applies the HasSuffix predicate on the "namespace" field.

func NamespaceIn

func NamespaceIn(vs ...string) predicate.Subject

NamespaceIn applies the In predicate on the "namespace" field.

func NamespaceLT

func NamespaceLT(v string) predicate.Subject

NamespaceLT applies the LT predicate on the "namespace" field.

func NamespaceLTE

func NamespaceLTE(v string) predicate.Subject

NamespaceLTE applies the LTE predicate on the "namespace" field.

func NamespaceNEQ

func NamespaceNEQ(v string) predicate.Subject

NamespaceNEQ applies the NEQ predicate on the "namespace" field.

func NamespaceNotIn

func NamespaceNotIn(vs ...string) predicate.Subject

NamespaceNotIn applies the NotIn predicate on the "namespace" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Subject) predicate.Subject

Or groups predicates with the OR operator between them.

func StripeCustomerID

func StripeCustomerID(v string) predicate.Subject

StripeCustomerID applies equality check predicate on the "stripe_customer_id" field. It's identical to StripeCustomerIDEQ.

func StripeCustomerIDContains

func StripeCustomerIDContains(v string) predicate.Subject

StripeCustomerIDContains applies the Contains predicate on the "stripe_customer_id" field.

func StripeCustomerIDContainsFold

func StripeCustomerIDContainsFold(v string) predicate.Subject

StripeCustomerIDContainsFold applies the ContainsFold predicate on the "stripe_customer_id" field.

func StripeCustomerIDEQ

func StripeCustomerIDEQ(v string) predicate.Subject

StripeCustomerIDEQ applies the EQ predicate on the "stripe_customer_id" field.

func StripeCustomerIDEqualFold

func StripeCustomerIDEqualFold(v string) predicate.Subject

StripeCustomerIDEqualFold applies the EqualFold predicate on the "stripe_customer_id" field.

func StripeCustomerIDGT

func StripeCustomerIDGT(v string) predicate.Subject

StripeCustomerIDGT applies the GT predicate on the "stripe_customer_id" field.

func StripeCustomerIDGTE

func StripeCustomerIDGTE(v string) predicate.Subject

StripeCustomerIDGTE applies the GTE predicate on the "stripe_customer_id" field.

func StripeCustomerIDHasPrefix

func StripeCustomerIDHasPrefix(v string) predicate.Subject

StripeCustomerIDHasPrefix applies the HasPrefix predicate on the "stripe_customer_id" field.

func StripeCustomerIDHasSuffix

func StripeCustomerIDHasSuffix(v string) predicate.Subject

StripeCustomerIDHasSuffix applies the HasSuffix predicate on the "stripe_customer_id" field.

func StripeCustomerIDIn

func StripeCustomerIDIn(vs ...string) predicate.Subject

StripeCustomerIDIn applies the In predicate on the "stripe_customer_id" field.

func StripeCustomerIDIsNil

func StripeCustomerIDIsNil() predicate.Subject

StripeCustomerIDIsNil applies the IsNil predicate on the "stripe_customer_id" field.

func StripeCustomerIDLT

func StripeCustomerIDLT(v string) predicate.Subject

StripeCustomerIDLT applies the LT predicate on the "stripe_customer_id" field.

func StripeCustomerIDLTE

func StripeCustomerIDLTE(v string) predicate.Subject

StripeCustomerIDLTE applies the LTE predicate on the "stripe_customer_id" field.

func StripeCustomerIDNEQ

func StripeCustomerIDNEQ(v string) predicate.Subject

StripeCustomerIDNEQ applies the NEQ predicate on the "stripe_customer_id" field.

func StripeCustomerIDNotIn

func StripeCustomerIDNotIn(vs ...string) predicate.Subject

StripeCustomerIDNotIn applies the NotIn predicate on the "stripe_customer_id" field.

func StripeCustomerIDNotNil

func StripeCustomerIDNotNil() predicate.Subject

StripeCustomerIDNotNil applies the NotNil predicate on the "stripe_customer_id" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Subject

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Subject

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Subject

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Subject

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Subject

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Subject

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Subject

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Subject

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Subject

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Subject queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByDisplayName

func ByDisplayName(opts ...sql.OrderTermOption) OrderOption

ByDisplayName orders the results by the display_name field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByKey

func ByKey(opts ...sql.OrderTermOption) OrderOption

ByKey orders the results by the key field.

func ByNamespace

func ByNamespace(opts ...sql.OrderTermOption) OrderOption

ByNamespace orders the results by the namespace field.

func ByStripeCustomerID

func ByStripeCustomerID(opts ...sql.OrderTermOption) OrderOption

ByStripeCustomerID orders the results by the stripe_customer_id field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

Jump to