Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Subject) predicate.Subject
- func CreatedAt(v time.Time) predicate.Subject
- func CreatedAtEQ(v time.Time) predicate.Subject
- func CreatedAtGT(v time.Time) predicate.Subject
- func CreatedAtGTE(v time.Time) predicate.Subject
- func CreatedAtIn(vs ...time.Time) predicate.Subject
- func CreatedAtLT(v time.Time) predicate.Subject
- func CreatedAtLTE(v time.Time) predicate.Subject
- func CreatedAtNEQ(v time.Time) predicate.Subject
- func CreatedAtNotIn(vs ...time.Time) predicate.Subject
- func DisplayName(v string) predicate.Subject
- func DisplayNameContains(v string) predicate.Subject
- func DisplayNameContainsFold(v string) predicate.Subject
- func DisplayNameEQ(v string) predicate.Subject
- func DisplayNameEqualFold(v string) predicate.Subject
- func DisplayNameGT(v string) predicate.Subject
- func DisplayNameGTE(v string) predicate.Subject
- func DisplayNameHasPrefix(v string) predicate.Subject
- func DisplayNameHasSuffix(v string) predicate.Subject
- func DisplayNameIn(vs ...string) predicate.Subject
- func DisplayNameIsNil() predicate.Subject
- func DisplayNameLT(v string) predicate.Subject
- func DisplayNameLTE(v string) predicate.Subject
- func DisplayNameNEQ(v string) predicate.Subject
- func DisplayNameNotIn(vs ...string) predicate.Subject
- func DisplayNameNotNil() predicate.Subject
- func ID(id string) predicate.Subject
- func IDContainsFold(id string) predicate.Subject
- func IDEQ(id string) predicate.Subject
- func IDEqualFold(id string) predicate.Subject
- func IDGT(id string) predicate.Subject
- func IDGTE(id string) predicate.Subject
- func IDIn(ids ...string) predicate.Subject
- func IDLT(id string) predicate.Subject
- func IDLTE(id string) predicate.Subject
- func IDNEQ(id string) predicate.Subject
- func IDNotIn(ids ...string) predicate.Subject
- func Key(v string) predicate.Subject
- func KeyContains(v string) predicate.Subject
- func KeyContainsFold(v string) predicate.Subject
- func KeyEQ(v string) predicate.Subject
- func KeyEqualFold(v string) predicate.Subject
- func KeyGT(v string) predicate.Subject
- func KeyGTE(v string) predicate.Subject
- func KeyHasPrefix(v string) predicate.Subject
- func KeyHasSuffix(v string) predicate.Subject
- func KeyIn(vs ...string) predicate.Subject
- func KeyLT(v string) predicate.Subject
- func KeyLTE(v string) predicate.Subject
- func KeyNEQ(v string) predicate.Subject
- func KeyNotIn(vs ...string) predicate.Subject
- func MetadataIsNil() predicate.Subject
- func MetadataNotNil() predicate.Subject
- func Namespace(v string) predicate.Subject
- func NamespaceContains(v string) predicate.Subject
- func NamespaceContainsFold(v string) predicate.Subject
- func NamespaceEQ(v string) predicate.Subject
- func NamespaceEqualFold(v string) predicate.Subject
- func NamespaceGT(v string) predicate.Subject
- func NamespaceGTE(v string) predicate.Subject
- func NamespaceHasPrefix(v string) predicate.Subject
- func NamespaceHasSuffix(v string) predicate.Subject
- func NamespaceIn(vs ...string) predicate.Subject
- func NamespaceLT(v string) predicate.Subject
- func NamespaceLTE(v string) predicate.Subject
- func NamespaceNEQ(v string) predicate.Subject
- func NamespaceNotIn(vs ...string) predicate.Subject
- func Not(p predicate.Subject) predicate.Subject
- func Or(predicates ...predicate.Subject) predicate.Subject
- func StripeCustomerID(v string) predicate.Subject
- func StripeCustomerIDContains(v string) predicate.Subject
- func StripeCustomerIDContainsFold(v string) predicate.Subject
- func StripeCustomerIDEQ(v string) predicate.Subject
- func StripeCustomerIDEqualFold(v string) predicate.Subject
- func StripeCustomerIDGT(v string) predicate.Subject
- func StripeCustomerIDGTE(v string) predicate.Subject
- func StripeCustomerIDHasPrefix(v string) predicate.Subject
- func StripeCustomerIDHasSuffix(v string) predicate.Subject
- func StripeCustomerIDIn(vs ...string) predicate.Subject
- func StripeCustomerIDIsNil() predicate.Subject
- func StripeCustomerIDLT(v string) predicate.Subject
- func StripeCustomerIDLTE(v string) predicate.Subject
- func StripeCustomerIDNEQ(v string) predicate.Subject
- func StripeCustomerIDNotIn(vs ...string) predicate.Subject
- func StripeCustomerIDNotNil() predicate.Subject
- func UpdatedAt(v time.Time) predicate.Subject
- func UpdatedAtEQ(v time.Time) predicate.Subject
- func UpdatedAtGT(v time.Time) predicate.Subject
- func UpdatedAtGTE(v time.Time) predicate.Subject
- func UpdatedAtIn(vs ...time.Time) predicate.Subject
- func UpdatedAtLT(v time.Time) predicate.Subject
- func UpdatedAtLTE(v time.Time) predicate.Subject
- func UpdatedAtNEQ(v time.Time) predicate.Subject
- func UpdatedAtNotIn(vs ...time.Time) predicate.Subject
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDisplayName(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByKey(opts ...sql.OrderTermOption) OrderOption
- func ByNamespace(opts ...sql.OrderTermOption) OrderOption
- func ByStripeCustomerID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the subject type in the database. Label = "subject" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldNamespace holds the string denoting the namespace field in the database. FieldNamespace = "namespace" // FieldKey holds the string denoting the key field in the database. FieldKey = "key" // FieldDisplayName holds the string denoting the display_name field in the database. FieldDisplayName = "display_name" // FieldStripeCustomerID holds the string denoting the stripe_customer_id field in the database. FieldStripeCustomerID = "stripe_customer_id" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the subject in the database. Table = "subjects" )
Variables ¶
var ( // NamespaceValidator is a validator for the "namespace" field. It is called by the builders before save. NamespaceValidator func(string) error // KeyValidator is a validator for the "key" field. It is called by the builders before save. KeyValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() string )
var Columns = []string{ FieldID, FieldNamespace, FieldKey, FieldDisplayName, FieldStripeCustomerID, FieldMetadata, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for subject fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func DisplayName ¶
DisplayName applies equality check predicate on the "display_name" field. It's identical to DisplayNameEQ.
func DisplayNameContains ¶
DisplayNameContains applies the Contains predicate on the "display_name" field.
func DisplayNameContainsFold ¶
DisplayNameContainsFold applies the ContainsFold predicate on the "display_name" field.
func DisplayNameEQ ¶
DisplayNameEQ applies the EQ predicate on the "display_name" field.
func DisplayNameEqualFold ¶
DisplayNameEqualFold applies the EqualFold predicate on the "display_name" field.
func DisplayNameGT ¶
DisplayNameGT applies the GT predicate on the "display_name" field.
func DisplayNameGTE ¶
DisplayNameGTE applies the GTE predicate on the "display_name" field.
func DisplayNameHasPrefix ¶
DisplayNameHasPrefix applies the HasPrefix predicate on the "display_name" field.
func DisplayNameHasSuffix ¶
DisplayNameHasSuffix applies the HasSuffix predicate on the "display_name" field.
func DisplayNameIn ¶
DisplayNameIn applies the In predicate on the "display_name" field.
func DisplayNameIsNil ¶
DisplayNameIsNil applies the IsNil predicate on the "display_name" field.
func DisplayNameLT ¶
DisplayNameLT applies the LT predicate on the "display_name" field.
func DisplayNameLTE ¶
DisplayNameLTE applies the LTE predicate on the "display_name" field.
func DisplayNameNEQ ¶
DisplayNameNEQ applies the NEQ predicate on the "display_name" field.
func DisplayNameNotIn ¶
DisplayNameNotIn applies the NotIn predicate on the "display_name" field.
func DisplayNameNotNil ¶
DisplayNameNotNil applies the NotNil predicate on the "display_name" field.
func IDContainsFold ¶
IDContainsFold applies the ContainsFold predicate on the ID field.
func IDEqualFold ¶
IDEqualFold applies the EqualFold predicate on the ID field.
func KeyContains ¶
KeyContains applies the Contains predicate on the "key" field.
func KeyContainsFold ¶
KeyContainsFold applies the ContainsFold predicate on the "key" field.
func KeyEqualFold ¶
KeyEqualFold applies the EqualFold predicate on the "key" field.
func KeyHasPrefix ¶
KeyHasPrefix applies the HasPrefix predicate on the "key" field.
func KeyHasSuffix ¶
KeyHasSuffix applies the HasSuffix predicate on the "key" field.
func MetadataIsNil ¶
MetadataIsNil applies the IsNil predicate on the "metadata" field.
func MetadataNotNil ¶
MetadataNotNil applies the NotNil predicate on the "metadata" field.
func Namespace ¶
Namespace applies equality check predicate on the "namespace" field. It's identical to NamespaceEQ.
func NamespaceContains ¶
NamespaceContains applies the Contains predicate on the "namespace" field.
func NamespaceContainsFold ¶
NamespaceContainsFold applies the ContainsFold predicate on the "namespace" field.
func NamespaceEQ ¶
NamespaceEQ applies the EQ predicate on the "namespace" field.
func NamespaceEqualFold ¶
NamespaceEqualFold applies the EqualFold predicate on the "namespace" field.
func NamespaceGT ¶
NamespaceGT applies the GT predicate on the "namespace" field.
func NamespaceGTE ¶
NamespaceGTE applies the GTE predicate on the "namespace" field.
func NamespaceHasPrefix ¶
NamespaceHasPrefix applies the HasPrefix predicate on the "namespace" field.
func NamespaceHasSuffix ¶
NamespaceHasSuffix applies the HasSuffix predicate on the "namespace" field.
func NamespaceIn ¶
NamespaceIn applies the In predicate on the "namespace" field.
func NamespaceLT ¶
NamespaceLT applies the LT predicate on the "namespace" field.
func NamespaceLTE ¶
NamespaceLTE applies the LTE predicate on the "namespace" field.
func NamespaceNEQ ¶
NamespaceNEQ applies the NEQ predicate on the "namespace" field.
func NamespaceNotIn ¶
NamespaceNotIn applies the NotIn predicate on the "namespace" field.
func StripeCustomerID ¶
StripeCustomerID applies equality check predicate on the "stripe_customer_id" field. It's identical to StripeCustomerIDEQ.
func StripeCustomerIDContains ¶
StripeCustomerIDContains applies the Contains predicate on the "stripe_customer_id" field.
func StripeCustomerIDContainsFold ¶
StripeCustomerIDContainsFold applies the ContainsFold predicate on the "stripe_customer_id" field.
func StripeCustomerIDEQ ¶
StripeCustomerIDEQ applies the EQ predicate on the "stripe_customer_id" field.
func StripeCustomerIDEqualFold ¶
StripeCustomerIDEqualFold applies the EqualFold predicate on the "stripe_customer_id" field.
func StripeCustomerIDGT ¶
StripeCustomerIDGT applies the GT predicate on the "stripe_customer_id" field.
func StripeCustomerIDGTE ¶
StripeCustomerIDGTE applies the GTE predicate on the "stripe_customer_id" field.
func StripeCustomerIDHasPrefix ¶
StripeCustomerIDHasPrefix applies the HasPrefix predicate on the "stripe_customer_id" field.
func StripeCustomerIDHasSuffix ¶
StripeCustomerIDHasSuffix applies the HasSuffix predicate on the "stripe_customer_id" field.
func StripeCustomerIDIn ¶
StripeCustomerIDIn applies the In predicate on the "stripe_customer_id" field.
func StripeCustomerIDIsNil ¶
StripeCustomerIDIsNil applies the IsNil predicate on the "stripe_customer_id" field.
func StripeCustomerIDLT ¶
StripeCustomerIDLT applies the LT predicate on the "stripe_customer_id" field.
func StripeCustomerIDLTE ¶
StripeCustomerIDLTE applies the LTE predicate on the "stripe_customer_id" field.
func StripeCustomerIDNEQ ¶
StripeCustomerIDNEQ applies the NEQ predicate on the "stripe_customer_id" field.
func StripeCustomerIDNotIn ¶
StripeCustomerIDNotIn applies the NotIn predicate on the "stripe_customer_id" field.
func StripeCustomerIDNotNil ¶
StripeCustomerIDNotNil applies the NotNil predicate on the "stripe_customer_id" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Subject queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDisplayName ¶
func ByDisplayName(opts ...sql.OrderTermOption) OrderOption
ByDisplayName orders the results by the display_name field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByKey ¶
func ByKey(opts ...sql.OrderTermOption) OrderOption
ByKey orders the results by the key field.
func ByNamespace ¶
func ByNamespace(opts ...sql.OrderTermOption) OrderOption
ByNamespace orders the results by the namespace field.
func ByStripeCustomerID ¶
func ByStripeCustomerID(opts ...sql.OrderTermOption) OrderOption
ByStripeCustomerID orders the results by the stripe_customer_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.