Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OnceValues ¶
OnceValues executes a function at most once and returns the cached result. This function behaves like sync.OnceValues, including caching both return values from the first call, but with a context argument to the function.
Can be used to do lazy database lookups that may be needed by multiple callbacks but should execute at most once.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.